/**
 * @fileoverview Task mixin
 * @license MIT
 * @author Rafal Pospiech <neuronet.io@gmail.com>
 * @package GanttElastic
 */

export default {
  computed: {
    /**
     * Get view box
     *
     * @returns {string}
     */
    getViewBox() {
      const task = this.task;
      return `0 0 ${task.width} ${task.height}`;
    },

    /**
     * Get group transform
     *
     * @returns {string}
     */
    getGroupTransform() {
      return `translate(${this.task.x} ${this.task.y})`;
    },

    /**
     * Should we display expander?
     *
     * @returns {boolean}
     */
    displayExpander() {
      const expander = this.root.state.options.chart.expander;
      return (
        expander.display ||
        (expander.displayIfTaskListHidden &&
          !this.root.state.options.taskList.display)
      );
    },
  },
  methods: {
    /**
     * Emit event
     *
     * @param {string} eventName
     * @param {Event} event
     */
    emitEvent(eventName, event) {
      this.root.$emit(`chart-${this.task.type}-${eventName}`, {
        event,
        data: this.task,
      });
    },
    emitPopoverEvent(type, position, eventName, event) {
      if (type === "circle") {
        this.root.$emit(`task-${type}-${eventName}`, {
          position,
          event,
          data: this.task,
        });
      } else {
        this.root.$emit(`task-${type}-${eventName}`, {
          event,
          data: this.task,
        });
      }
    },
    taskEmitEvent(position, eventName, event) {
      this.$emit(`task-event-${eventName}`, {
        position,
        event,
        data: this.task,
      });
    },
  },
};
